Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/artemis_sg/__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
src/artemis_sg/_version.py | 11 | 11 | 0 | 2 | 0 | 0%
src/artemis_sg/app_creds.py | 28 | 7 | 0 | 8 | 1 | 72%
src/artemis_sg/cli.py | 176 | 35 | 2 | 96 | 13 | 81%
src/artemis_sg/config/__init__.py | 49 | 26 | 0 | 22 | 2 | 44%
src/artemis_sg/gcloud.py | 65 | 49 | 2 | 12 | 0 | 21%
src/artemis_sg/img_downloader.py | 79 | 28 | 2 | 30 | 1 | 66%
src/artemis_sg/item.py | 28 | 1 | 0 | 8 | 1 | 94%
src/artemis_sg/items.py | 76 | 3 | 0 | 30 | 3 | 94%
src/artemis_sg/scraper.py | 599 | 149 | 0 | 98 | 29 | 71%
src/artemis_sg/slide_generator.py | 287 | 52 | 0 | 70 | 20 | 78%
src/artemis_sg/spreadsheet.py | 217 | 23 | 0 | 70 | 13 | 86%
src/artemis_sg/vendor.py | 22 | 3 | 0 | 2 | 1 | 83%
Total | 1641 | 387 | 6 | 448 | 84 | 74%

No items found using the specified filter.